summaryrefslogtreecommitdiffstats
path: root/twin-styles/smooth-blend/client/smoothblend.cc
diff options
context:
space:
mode:
Diffstat (limited to 'twin-styles/smooth-blend/client/smoothblend.cc')
-rw-r--r--twin-styles/smooth-blend/client/smoothblend.cc48
1 files changed, 24 insertions, 24 deletions
diff --git a/twin-styles/smooth-blend/client/smoothblend.cc b/twin-styles/smooth-blend/client/smoothblend.cc
index 8f0cf6a9..ab711bf4 100644
--- a/twin-styles/smooth-blend/client/smoothblend.cc
+++ b/twin-styles/smooth-blend/client/smoothblend.cc
@@ -94,7 +94,7 @@ KDecoration* smoothblendFactory::createDecoration(KDecorationBridge* b) {
// reset()
// -------
// Reset the handler. Returns true if decorations need to be remade, false if
// only a tqrepaint is necessary
bool smoothblendFactory::reset(unsigned long changed) {
// read in the configuration
@@ -232,7 +232,7 @@ void smoothblendButton::animate() {
animTmr->start(TIMERINTERVAL, true); // single-shot
}
}
- tqrepaint(false);
+ repaint(false);
}
//////////////////////////////////////////////////////////////////////////////
// enterEvent()
@@ -434,7 +434,7 @@ void smoothblendButton::drawButton( TQPainter *painter ) {
//that may produce pixilation of the image
painter->drawImage( dx, dy, menuButtonImage.smoothScale(newWidth, newHeight) );
} else {
//highlight on a mouse over tqrepaint
double factor = animProgress * 0.13;
if(!isDown())
@@ -836,7 +836,7 @@ void smoothblendClient::activeChange() {
for (int n=0; n<ButtonTypeCount; n++)
if (button[n])
button[n]->reset();
- widget()->tqrepaint(false);
+ widget()->repaint(false);
}
//////////////////////////////////////////////////////////////////////////////
@@ -845,7 +845,7 @@ void smoothblendClient::activeChange() {
// The title has changed
void smoothblendClient::captionChange() {
- widget()->tqrepaint(titlebar_->tqgeometry(), false);
+ widget()->repaint(titlebar_->geometry(), false);
}
//////////////////////////////////////////////////////////////////////////////
@@ -858,7 +858,7 @@ void smoothblendClient::desktopChange() {
if (button[ButtonSticky]) {
TQToolTip::remove(button[ButtonSticky]);
TQToolTip::add(button[ButtonSticky], d ? i18n("Un-Sticky") : i18n("Sticky"));
- button[ButtonSticky]->tqrepaint(false);
+ button[ButtonSticky]->repaint(false);
}
}
@@ -869,7 +869,7 @@ void smoothblendClient::desktopChange() {
void smoothblendClient::iconChange() {
if (button[ButtonMenu]) {
- button[ButtonMenu]->tqrepaint(false);
+ button[ButtonMenu]->repaint(false);
}
}
@@ -883,7 +883,7 @@ void smoothblendClient::maximizeChange() {
if (button[ButtonMax]) {
TQToolTip::remove(button[ButtonMax]);
TQToolTip::add(button[ButtonMax], m ? i18n("Restore") : i18n("Maximize"));
- button[ButtonMax]->tqrepaint(false);
+ button[ButtonMax]->repaint(false);
}
}
@@ -897,7 +897,7 @@ void smoothblendClient::shadeChange() {
if (button[ButtonShade]) {
TQToolTip::remove(button[ButtonShade]);
TQToolTip::add(button[ButtonShade], s ? i18n("Unshade") : i18n("Shade"));
- button[ButtonShade]->tqrepaint(false);
+ button[ButtonShade]->repaint(false);
}
}
@@ -909,7 +909,7 @@ void smoothblendClient::shadeChange() {
void smoothblendClient::keepAboveChange(bool a) {
if (button[ButtonAbove]) {
button[ButtonAbove]->setOn(a);
- button[ButtonAbove]->tqrepaint(false);
+ button[ButtonAbove]->repaint(false);
}
}
@@ -921,7 +921,7 @@ void smoothblendClient::keepAboveChange(bool a) {
void smoothblendClient::keepBelowChange(bool b) {
if (button[ButtonBelow]) {
button[ButtonBelow]->setOn(b);
- button[ButtonBelow]->tqrepaint(false);
+ button[ButtonBelow]->repaint(false);
}
}
@@ -1077,7 +1077,7 @@ bool smoothblendClient::eventFilter(TQObject *obj, TQEvent *e) {
// Doubleclick on title
void smoothblendClient::mouseDoubleClickEvent(TQMouseEvent *e) {
- if (titlebar_->tqgeometry().contains(e->pos()))
+ if (titlebar_->geometry().contains(e->pos()))
titlebarDblClickOperation();
}
@@ -1088,7 +1088,7 @@ void smoothblendClient::mouseDoubleClickEvent(TQMouseEvent *e) {
void smoothblendClient::wheelEvent(TQWheelEvent *e)
{
- if (titleLayout_->tqgeometry().contains(e->pos()) )
+ if (titleLayout_->geometry().contains(e->pos()) )
titlebarMouseWheelOperation( e->delta());
}
@@ -1120,15 +1120,15 @@ void smoothblendClient::paintEvent(TQPaintEvent*) {
group = options()->colorGroup(KDecoration::ColorTitleBar, isActive());
widgetGroup = widget()->colorGroup();
- TQRect topRect( topSpacer_->tqgeometry() );
- TQRect titleRect( titleLayout_->tqgeometry() );
- TQRect textRect( titlebar_->tqgeometry() );
- TQRect Rltitle( leftTitleSpacer_->tqgeometry() );
- TQRect Rrtitle( rightTitleSpacer_->tqgeometry() );
- TQRect Rdeco( decoSpacer_->tqgeometry() );
- TQRect Rleft( leftSpacer_->tqgeometry() );
- TQRect Rright( rightSpacer_->tqgeometry() );
- TQRect Rbottom( bottomSpacer_->tqgeometry() );
+ TQRect topRect( topSpacer_->geometry() );
+ TQRect titleRect( titleLayout_->geometry() );
+ TQRect textRect( titlebar_->geometry() );
+ TQRect Rltitle( leftTitleSpacer_->geometry() );
+ TQRect Rrtitle( rightTitleSpacer_->geometry() );
+ TQRect Rdeco( decoSpacer_->geometry() );
+ TQRect Rleft( leftSpacer_->geometry() );
+ TQRect Rright( rightSpacer_->geometry() );
+ TQRect Rbottom( bottomSpacer_->geometry() );
TQRect tempRect;
@@ -1280,7 +1280,7 @@ void smoothblendClient::updateMask() {
void smoothblendClient::resizeEvent(TQResizeEvent *) {
if (widget()->isShown()) {
TQRegion region = widget()->rect();
- region = region.subtract(titlebar_->tqgeometry());
+ region = region.subtract(titlebar_->geometry());
widget()->erase(region);
updateMask();
}
@@ -1293,7 +1293,7 @@ void smoothblendClient::resizeEvent(TQResizeEvent *) {
void smoothblendClient::showEvent(TQShowEvent *) {
updateMask();
- widget()->tqrepaint();
+ widget()->repaint();
}
//////////////////////////////////////////////////////////////////////////////
@@ -94,7 +94,7 @@ KDecoration* smoothblendFactory::createDecoration(KDecorationBridge* b) {
// -------
// Reset the handler. Returns true if decorations need to be remade, false if
-// only a tqrepaint is necessary
+// only a repaint is necessary
bool smoothblendFactory::reset(unsigned long changed) {
// read in the configuration
@@ -434,7 +434,7 @@ void smoothblendButton::drawButton( TQPainter *painter ) {
painter->drawImage( dx, dy, menuButtonImage.smoothScale(newWidth, newHeight) );
} else {
- //highlight on a mouse over tqrepaint
+ //highlight on a mouse over repaint
double factor = animProgress * 0.13;
if(!isDown())